/*
 * Copyright (c) 2012, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#ifndef PROTO_H
#define PROTO_H

#define MAX_PARAM_LEN   5
#define CMD_SET_PWM     0x20
#define CMD_SET_VOLT    0x21
#define CMD_SET_DATA    0x22
#define CMD_GET_DATA    0x23
#define CMD_LOAD_DATA   0x24
#define CMD_STORE_DATA  0x25

#define PARAM_CHAN_A    0x00
#define PARAM_CHAN_B    0x01

#define RES_NEGATIVE    0x00
#define RES_POSITIVE    0x01

struct frame {
	uint8_t  type;
	uint8_t  param[MAX_PARAM_LEN];
};

struct param_set_pwm {
	uint8_t  chan;   // channel
	uint8_t  pwm;    // duty cycle, 0 .. 255
};

struct param_set_volt {
	uint8_t  chan;   // channel
	uint16_t volt;   // voltage, millivolts
};

struct param_set_data {
	uint8_t  chan;   // channel
	uint8_t  index;  // data point index
	uint16_t xval;   // x value (voltage, millivolts)
	uint8_t  yval;   // y value (duty cycle, 0 .. 255)
};

struct param_get_data {
	uint8_t  chan;   // channel
	uint8_t  index;  // data point index
};

struct result_get_data {
	uint16_t xval;   // x value (voltage, millivolts)
	uint8_t  yval;   // y value (duty cycle, 0 .. 255)
};

#endif

