/*
 * Copyright (c) 2012, Felix Opatz
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice,
 *   this list of conditions and the following disclaimer.
 * * Redistributions in binary form must reproduce the above copyright
 *   notice, this list of conditions and the following disclaimer in the
 *   documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

#include <avr/io.h>

#include "usart.h"

#define BAUD_RATE  9600

void usart_tx_byte(uint8_t data)
{
	loop_until_bit_is_set(UCSRA, UDRE);
	UDR = data;
}

uint8_t usart_rx_byte(void)
{
	uint8_t data;
	
	loop_until_bit_is_set(UCSRA, RXC);
	data = UDR;
	
	return data;
}

void usart_init(void)
{
	// U2X
	UCSRA = (1 << U2X);
	// enable transmitter and receiver
	UCSRB = (1 << TXEN) | (1 << RXEN);
	// 8N1
	UCSRC = (1 << UCSZ1) | (1 << UCSZ0);
	// calculate baud rate register
	UBRRL = (uint8_t) (F_CPU/(8UL * BAUD_RATE)) - 1;
	UBRRH = 0;
}

